@@ -26,3 +26,7 @@ FRAME_LEN_HEADER = 'FrameLength'
 FRAME_OVERLAP_HEADER = 'FrameOverlap'
 BUFFER_OFFSET_HEADER = 'BufferOffset'
 RESERVATION_KEY_HEADER = 'ReservationKey'
+
+#  AMQP message headers ###############################################################################################
+USER_AMQP_HEADER: str = 'UserId'
+MODEL_AMQP_HEADER: str = 'ModelUid'
